pub fn contexts_deep_equal(context1: Context, context2: Context) -> bool
Check that two given contexts contain the same data, i.e. graphs, nodes, names, parameters.

Underlying structures that contain pointers (graphs, nodes) are compared by data they refer to.

Arguments

  • context1 - first context to compare
  • context2 - second context to compare

Returns

true if the given contexts contain the same content, otherwise false