Struct ciphercore_base::ops::comparisons::LessThanEqualTo
source · [−]pub struct LessThanEqualTo {
pub signed_comparison: bool,
}Expand description
A structure that defines the custom operation LessThanEqualTo that compares arrays of binary strings elementwise as follows:
If a and b are two bitstrings, then LessThanEqualTo(a,b) = 1 if a <= b and 0 otherwise.
The last dimension of both inputs must be the same; it defines the length of input bitstrings.
If input shapes are different, the broadcasting rules are applied (see the NumPy broadcasting rules).
For example, if input arrays are of shapes [2,3], and [1,3], the resulting array has shape [2].
To compare signed numbers, signed_comparison should be set true.
To use this and other custom operations in computation graphs, see Graph::custom_op.
Custom operation arguments
- Node containing a binary array or scalar
- Node containing a binary array or scalar
Custom operation returns
New LessThanEqualTo node
Example
let c = create_context().unwrap();
let g = c.create_graph().unwrap();
let t = array_type(vec![2, 3], BIT);
let n1 = g.input(t.clone()).unwrap();
let n2 = g.input(t.clone()).unwrap();
let n3 = g.custom_op(CustomOperation::new(LessThanEqualTo {signed_comparison: true}), vec![n1, n2]).unwrap();Fields
signed_comparison: boolBoolean value indicating whether input bitstring represent signed integers