Module min_max

Module min_max 

Minimum and maximum operations. They operate on unsigned integers represented as bitstrings.

Structs

Max
A structure that defines the custom operation Max that computes the maximum of length-n bitstring arrays elementwise.
Min
A structure that defines the custom operation Min that computes the minimum of length-n bitstring arrays elementwise.