Function ciphercore_base::graphs::contexts_deep_equal
source · [−]Expand description
Check that two given contexts contain the same data, i.e. graphs, nodes, names, parameters.
Underlying structures that contain pointers (graphs, nodes) are compared by data they refer to.
Arguments
context1- first context to comparecontext2- second context to compare
Returns
true if the given contexts contain the same content, otherwise false